It is raised when the cache cannot be retrieved from the registry because it was not started or does not exist.
The type for this exception struct.
@type t() :: %Nebulex.CacheNotFoundError{ __exception__: true, cache: atom() | pid(), message: binary() }
This exception has the following public fields:
:message - the error message.
:message
:cache - the cache name or its PID.
:cache