Nebulex.Telemetry.CacheEntryHandler (Nebulex v3.0.0)

Copy Markdown View Source

A Telemetry handler listens to cache command completion events, builds the corresponding cache entry event, and applies the provided filter and listener.

Summary

Functions

Registers a new Telemetry handler for listening and handling cache entry events.

Un-registers a Telemetry handler that listens and handles cache entry events.

Functions

register(map, listener, filter, meta, opts)

Registers a new Telemetry handler for listening and handling cache entry events.

unregister(map, id, opts)

Un-registers a Telemetry handler that listens and handles cache entry events.