A Telemetry handler listens to cache command completion events, builds the corresponding cache entry event, and applies the provided filter and listener.
Summary
Functions
Registers a new Telemetry handler for listening and handling cache entry events.
Un-registers a Telemetry handler that listens and handles cache entry events.
Functions
@spec register( Nebulex.Adapter.adapter_meta(), Nebulex.Event.listener(), Nebulex.Event.filter(), Nebulex.Event.metadata(), keyword() ) :: :ok | Nebulex.Error.t()
Registers a new Telemetry handler for listening and handling cache entry events.
Un-registers a Telemetry handler that listens and handles cache entry events.